@@ -51,7 +51,7 @@ def ls(folder:str):
     body=dumps(body)
     url='https://api.dropboxapi.com/2/files/list_folder'
     r=http(url,Method=POST,Header=header,Body=body)
-    #print(r)
+    print(r)
     if(r['status']<=-1):
         return r['status']
     if(r['code']==401):
@@ -382,7 +382,7 @@ def ls_l(folder:str):
         if(i['.tag']=='folder'):
             result[i['name']]=[]
         else:
-            result[i['name']]=[i['size'],i['client_modified'],i['server_modified']]
+            result[i['name']]=[i['size'],toUnix(i['client_modified']),toUnix(i['server_modified'])]
     return result
 
 
@@ -412,7 +412,7 @@ def getFileProperty(file:str):
         return -20
     if(r['text']['.tag']!='file'):
         return -15
-    return [r['text']['size'],r['text']['client_modified'],r['text']['server_modified']]
+    return [r['text']['size'],toUnix(r['text']['client_modified']),toUnix(r['text']['server_modified'])]
 
 def search():
     pass
